<?php

/**
 * @file
 * Placeholder replacement tokens for commerce checkout url.
 */

/**
 * Implements hook_token_info().
 */
function commerce_checkout_url_token_info() {
  // Tokens for orders.
  $order = array();

  $order['commerce-checkout-url-expire'] = array(
    'name' => t('Commerce Checkout URL expiry date'),
    'description' => t('The date when a one-time link to the checkout page generated now will expire.'),
  );
  $order['commerce-checkout-url'] = array(
    'name' => t('Commerce Checkout URL.'),
    'description' => t('A one-time link to the checkout page of an order protected with an authentication code.'),
  );

  return array(
    'tokens' => array(
      'commerce-order' => $order,
    ),
  );
}

/**
 * Implements hook_tokens().
 */
function commerce_checkout_url_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $language_code = isset($options['language']) ? $options['language']->language : NULL;
  $sanitize = !empty($options['sanitize']);

  $replacements = array();
  if ($type === 'commerce-order' && !empty($data['commerce-order'])) {
    $order = $data['commerce-order'];
    $ttl = (int) variable_get('commerce_checkout_url_ttl', COMMERCE_CHECKOUT_URL_DEFAULT_TTL);
    $commerce_checkout_url_expire = REQUEST_TIME + $ttl;

    foreach ($tokens as $name => $original) {
      switch ($name) {
        case 'commerce-checkout-url':
          $url = commerce_checkout_url_create_url($order, $commerce_checkout_url_expire);
          $replacements[$original] = $sanitize ? check_plain($url) : $url;
          break;

        case 'commerce-checkout-url-expire':
          $replacements[$original] = format_date($commerce_checkout_url_expire, 'medium', '', NULL, $language_code);
          break;
      }
    }

    if ($date_tokens = token_find_with_prefix($tokens, 'commerce-checkout-url-expire')) {
      $replacements += token_generate('date', $date_tokens, array('date' => $commerce_checkout_url_expire), $options);
    }
  }

  return $replacements;
}
