<?php

namespace Drupal\commerce_checkout_url\Tests;

/**
 * Tests token integration.
 */
class TokenTest extends \DrupalWebTestCase {

  protected $profile = 'testing';

  /**
   * {@inheritdoc}
   */
  public static function getInfo() {
    return array(
      'name' => 'Token integration',
      'description' => 'Tests token integration.',
      'group' => 'Commerce Checkout URL',
    );
  }

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp(array('commerce_checkout_url'));
  }

  /**
   * Tests token integration.
   */
  public function testTokenIntegration() {
    $order = commerce_order_new(0);

    $text = 'Your order is accessible until [commerce-order:commerce-checkout-url-expire] using the following link [commerce-order:commerce-checkout-url]';
    $pattern = '#^Your order is accessible until (.*) using the following link (.*)$#';
    $expected_date = REQUEST_TIME + COMMERCE_CHECKOUT_URL_DEFAULT_TTL;
    $expected_base = url(COMMERCE_CHECKOUT_URL_DEFAULT_MENU_ITEM_PATH, array('absolute' => TRUE));

    $result = token_replace($text, array('commerce-order' => $order));
    $status = preg_match($pattern, $result, $matches);
    $this->assertTrue($status);
    $this->assertIdentical(format_date($expected_date, 'medium'), $matches[1]);
    $this->assertIdentical(strpos($matches[2], $expected_base), 0);

    $text = 'Your order is accessible until [commerce-order:commerce-checkout-url-expire:long] using the following link [commerce-order:commerce-checkout-url]';
    $result = token_replace($text, array('commerce-order' => $order));
    $status = preg_match($pattern, $result, $matches);
    $this->assertTrue($status);
    $this->assertIdentical(format_date($expected_date, 'long'), $matches[1]);
    $this->assertIdentical(strpos($matches[2], $expected_base), 0);
  }

}
